require "import"
import "android.speech.tts.TextToSpeech"
import "java.util.Locale"

local tts

local function announceDateTime()
    local days = {"اتوار", "پیر", "منگل", "بدھ", "جمعرات", "جمعہ", "ہفتہ"}
    local months = {"جنوری", "فروری", "مارچ", "اپریل", "مئی", "جون", "جولائی", "اگست", "ستمبر", "اکتوبر", "نومبر", "دسمبر"}

    local today = os.date("*t")
    local dayOfWeek = days[today.wday]
    local dayOfMonth = today.day
    local month = months[today.month]
    local year = today.year

    local hour = today.hour
    local minute = today.min

    local period = ""

    if hour >= 20 or hour < 5 then
        period = "رات کے"
    elseif hour >= 5 and hour < 12 then
        period = "صبح کے"
    elseif hour >= 12 and hour < 15 then
        period = "دوپہر کے"
    elseif hour >= 15 and hour < 17 then
        period = "سہ پہر کے"
    else
        period = "شام کے"
    end

    if hour > 12 then
        hour = hour - 12
    elseif hour == 0 then
        hour = 12
    end

    -- اگر منٹ 1 ہو تو "ہو رہا ہے" ورنہ "ہو رہے ہیں"
    local minutePhrase = (minute == 1) and "ہو رہا ہے" or "ہو رہے ہیں"

    local timeString = string.format("اس وقت %s %d بج کر %d منٹ %s", period, hour, minute, minutePhrase)
    local dateString = string.format("اور آج %s، %d %s %d ہے۔", dayOfWeek, dayOfMonth, month, year)
    
    local announcement = timeString .. " " .. dateString

    tts.speak(announcement, TextToSpeech.QUEUE_FLUSH, nil, nil)
end

local function initTTS()
    tts = luajava.new(TextToSpeech, service, TextToSpeech.OnInitListener {
        onInit = function(status)
            if status == TextToSpeech.SUCCESS then
                tts.setLanguage(Locale("ur"))
                announceDateTime()
            end
        end
    })
end

initTTS()

return true